{% load static %}
{# An info popup with a close button in the top-right corner. #}
<section id="info-popup" class="popup-wrapper">
    <div class="popup-box">
        <div class="popup-box__title justify-content-end">
            <button type="button" onclick="hideInfoPopup()" class="close popup-box__close" aria-label="Close">
                <span class="iconify" data-icon="mdi:close"></span>
            </button>
        </div>
        <div class="popup-box__title"><h5 class="mt-1"></h5></div>
        <div class="popup-box__msg"></div>
    </div>
</section>
