{% extends 'portal/base.html' %}

{% block content %}

<h2>Something went wrong...</h2><br>

<p>Sorry, something went wrong when loading the page. <a href="#" id="csrfTryAgain">Try again</a>.</p>

<script>
    $(function() {
        $("#csrfTryAgain").click(function() {
            window.location = window.location.href;
            event.preventDefault();
        });
    });
</script>

{% endblock content %}