{% load static %}
{# A confirmation popup with Cancel and Confirm buttons. #}
<section id="popup" class="popup-wrapper">
    <div class="popup-box">
        <div>
            <button type="button" onclick="hidePopupConfirmation()" class="close popup-box__close" aria-label="Close">
                <span class="iconify" data-icon="mdi:close"></span>
            </button>
        </div>
        <div class="popup-box__title"></div>
        <div class="popup-box__msg"></div>
        <div class="popup-box__buttons">
            <a id="cancel_button" class="button button--small button--secondary button--secondary--dark" onclick="hidePopupConfirmation()" aria-labelledby="cancel_button"> Cancel </a>
            <a id="confirm_button" class='button button--small button--primary' onclick="" aria-labelledby="confirm_button"> Confirm </a>
        </div>
    </div>
</section>
