{% extends 'portal/base.html' %}

{% block check_user_status %}
    {# remove script that checks user_status as admin accounts do not have userProfile #}
{% endblock check_user_status %}

{% block topBar %}
{# remove topBar that checks user_status as admin accounts do not have userProfile #}
{% endblock topBar %}

{% block subNav %}
    {# remove subNav that checks user_status as admin accounts do not have userProfile #}
{% endblock subNav %}
