{# Overriding the original "two_factor" template #}
<div class="background">
    <div class="d-flex flex-column align-items-start">

        {{ wizard.management_form }}
        {{ wizard.form }}
        <small>Enter your code from your app</small>
    </div>
</div>
