{% extends 'portal/form_shapes.html' %}
{% load static %}
{% load app_tags %}

{% block form_content %}
    <div id="emailVerificationNeeded_page"></div>
    <h4>We need to verify your email address</h4>
    <h5>An email has been sent to you. Make sure to check your
        <strong>spam</strong>.</h5>
    <img class="background" title="Paper Plane" alt="Verification email sent" src="{% static 'portal/img/paper_plane.png' %}">
    <p class="text-left">Please follow the link within the email to verify your details. This will expire in one hour.</p>
    <div>
        <a target="_blank" href="https://mail.google.com/mail/#search/from%3Ano-reply%40info.codeforlife.education+subject%3AEmail+Verification"
           class="button button--home button-email">Open in Gmail</a>
        <a target="_blank" href="https://outlook.live.com/mail/"
           class="button button--home button-email">Open in Outlook</a>
    </div>
    <p class="text-left"><a id="home_button" href="{% url 'home' %}">&lt; back to homepage</a></p>
{% endblock form_content %}
